Skip to contents

Select a piece of text with a cursor and call these functions as an add-in to enclose the text with special symbols. Text between $.$ is interpreted as an inline equation and between $$.$$ or \[.\] as a block equation in Quarto/Pandoc Markdown.

Usage

qmd_equation_inline(context = rs_get_context())

qmd_equation_block(context = rs_get_context())

qmd_equation_block2(context = rs_get_context())

Arguments

context

(class document_context)
Object with context of active RStudio document.

See also

Other Quarto formatting add-ins: format_md, qmd_code_block(), qmd_list()